@@ -9,7 +9,9 @@ import hashlib
 from PySide6.QtWidgets import QMessageBox
 from PySide6.QtCore import QObject, QCoreApplication, Signal, Property
 
-from pupgui2.util import ghapi_rlcheck, extract_tar
+from pupgui2.datastructures import Launcher
+from pupgui2.util import fetch_project_release_data, fetch_project_releases
+from pupgui2.util import get_launcher_from_installdir, extract_tar
 from pupgui2.util import build_headers_with_authorization
 from pupgui2.networkutil import download_file
 
@@ -99,19 +101,8 @@ class CtInstaller(QObject):
         Content(s):
             'version', 'date', 'download', 'size', 'checksum'
         """
-        url = self.CT_URL + (f'/tags/{tag}' if tag else '/latest')
-        data = self.rs.get(url).json()
-        if 'tag_name' not in data:
-            return None
 
-        values = {'version': data['tag_name'], 'date': data['published_at'].split('T')[0]}
-        for asset in data['assets']:
-            if asset['name'].endswith('sha512sum'):
-                values['checksum'] = asset['browser_download_url']
-            elif asset['name'].endswith(self.release_format):
-                values['download'] = asset['browser_download_url']
-                values['size'] = asset['size']
-        return values
+        return fetch_project_release_data(self.CT_URL, self.release_format, self.rs, tag=tag, checksum_suffix='.sha512sum')
 
     def __get_data(self, version: str, install_dir: str) -> tuple[dict | None, str | None]:
 
@@ -128,31 +119,37 @@ class CtInstaller(QObject):
 
         return (data, protondir)
 
-    def is_system_compatible(self):
+    def is_system_compatible(self) -> bool:
         """
         Are the system requirements met?
         Return Type: bool
         """
         return True
 
-    def fetch_releases(self, count=100, page=1):
+    def fetch_releases(self, count: int = 100, page: int = 1) -> list[str]:
         """
         List available releases
         Return Type: str[]
         """
-        return [release['tag_name'] for release in ghapi_rlcheck(self.rs.get(f'{self.CT_URL}?per_page={count}&page={page}').json()) if 'tag_name' in release]
+
+        return fetch_project_releases(self.CT_URL, self.rs, count=count)
 
     def get_tool(self, version, install_dir, temp_dir):
         """
         Download and install the compatibility tool
         Return Type: bool
         """
+
+        install_dir = self.get_extract_dir(install_dir)
+
         data, protondir = self.__get_data(version, install_dir)
         if not data:
             return False
 
+        # Note: protondir is only used for checksums
         if not protondir or  not os.path.exists(protondir):
-            protondir = os.path.join(install_dir, 'Proton-' + data['version'])
+            protondir = os.path.join(install_dir, 'Proton-' + data['version'])  # Check if we have an older Proton-GE folder name
+
         checksum_dir = f'{protondir}/sha512sum'
         source_checksum = self.rs.get(data['checksum']).text if 'checksum' in data else None
         local_checksum = open(checksum_dir).read() if os.path.exists(checksum_dir) else None
@@ -182,6 +179,26 @@ class CtInstaller(QObject):
 
         return True
 
+    def get_extract_dir(self, install_dir: str) -> str:
+
+        """
+        Return the directory to extract GE-Proton archive based on the current launcher
+        Return Type: str
+        """
+
+        launcher = get_launcher_from_installdir(install_dir)
+        extract_dir: str = install_dir
+
+        if launcher == Launcher.LUTRIS:
+            # GE-Proton for Lutris needs to go into 'runners/proton' and not 'runners/wine'
+            extract_dir = os.path.abspath(os.path.join(install_dir, '../../runners/proton'))
+            
+            # Lutris may not be guaranteed to make this path, so ensure it exists
+            if not os.path.exists(extract_dir):
+                os.mkdir(extract_dir)
+
+        return extract_dir  # Default to install_dir
+
     def get_info_url(self, version: str) -> str:
         """
         Get link with info about version (eg. GitHub release page)
