@@ -2,9 +2,9 @@
 # cyrv6737's NorthstarProton for TitanFall 2
 # Copyright (C) 2022 DavidoTek, partially based on AUNaseef's protonup
 
-from PySide6.QtCore import QObject, Signal, Property, QCoreApplication
+from PySide6.QtCore import QCoreApplication
 
-from pupgui2.util import fetch_project_release_data, fetch_project_releases
+from pupgui2.util import fetch_project_release_data
 
 from pupgui2.resources.ctmods.ctmod_00protonge import CtInstaller as GEProtonInstaller
 
@@ -26,14 +26,6 @@ class CtInstaller(GEProtonInstaller):
 
         self.release_format: str = 'tar.gz'
 
-    def fetch_releases(self, count: int = 100, page: int = 1) -> list[str]:
-        """
-        List available releases
-        Return Type: str[]
-        """
-
-        return fetch_project_releases(self.CT_URL, self.rs, count=count, page=page)
-
     def __fetch_github_data(self, tag: str) -> dict:
         """
         Fetch GitHub release information
